@@ -1,45 +1,44 @@
 package Prophet::Replica::sqlite;
+{
+  $Prophet::Replica::sqlite::VERSION = '0.751';
+}
 use Any::Moose;
 extends 'Prophet::Replica';
 use Params::Validate qw(:all);
-use File::Spec  ();
+use File::Spec ();
 use File::Path;
 use Prophet::Util;
 use JSON;
 use Digest::SHA qw/sha1_hex/;
 use DBI;
 
-=head1 METHODS
-
-=cut
-
 has dbh => (
-    is => 'rw',
+    is      => 'rw',
     isa     => 'DBI::db',
-    lazy => 1,
+    lazy    => 1,
     default => sub {
         my $self = shift;
         my $dbh;
         die "I couldn't determine a filesystem root from the given URL.\n"
-        ."Correct syntax is (sqlite:)file:///replica/root .\n"
-            unless $self->db_file;
+          . "Correct syntax is (sqlite:)file:///replica/root .\n"
+          unless $self->db_file;
         eval {
             $dbh = DBI->connect(
                 "dbi:SQLite:" . $self->db_file,
-                undef, undef,
-                { RaiseError => 1, AutoCommit => 1 },
+                undef, undef, { RaiseError => 1, AutoCommit => 1 },
             );
+            $dbh->do("PRAGMA synchronous = OFF");
         };
         if ($@) {
-            die "Unable to open the database file '".$self->db_file
-                ."'. Is this a readable SQLite replica?\n";
+            die "Unable to open the database file '" . $self->db_file
+              . "'. Is this a readable SQLite replica?\n";
         }
         return $dbh;
-     }
+    }
 );
 
 sub db_file {
-    my $self = shift;
+    my $self    = shift;
     my $fs_root = $self->fs_root;
 
     return defined $fs_root ? "$fs_root/db.sqlite" : undef;
@@ -84,9 +83,9 @@ has fs_root => (
 has current_edit => ( is => 'rw', );
 
 has current_edit_records => (
-    is        => 'rw',
-    isa       => 'ArrayRef',
-    default   => sub { [] },
+    is      => 'rw',
+    isa     => 'ArrayRef',
+    default => sub { [] },
 );
 
 has '+resolution_db_handle' => (
@@ -94,9 +93,10 @@ has '+resolution_db_handle' => (
     lazy    => 1,
     default => sub {
         my $self = shift;
-        return if $self->is_resdb ;
+        return if $self->is_resdb;
         return Prophet::Replica->get_handle(
-            {   url        => $self->url . '/resolutions',
+            {
+                url        => $self->url . '/resolutions',
                 app_handle => $self->app_handle,
                 is_resdb   => 1,
             }
@@ -111,28 +111,28 @@ sub has_cached_prop {
     my $prop = shift;
 
     # $self->uuid is the replica's uuid
-    return exists $PROP_CACHE->{$self->uuid}->{$prop};
+    return exists $PROP_CACHE->{ $self->uuid }->{$prop};
 }
 
 sub fetch_cached_prop {
     my $self = shift;
     my $prop = shift;
 
-    return $PROP_CACHE->{$self->uuid}->{$prop};
+    return $PROP_CACHE->{ $self->uuid }->{$prop};
 }
 
 sub set_cached_prop {
     my $self = shift;
-    my ($prop, $value) = @_;
+    my ( $prop, $value ) = @_;
 
-    $PROP_CACHE->{$self->uuid}->{$prop} = $value;
+    $PROP_CACHE->{ $self->uuid }->{$prop} = $value;
 }
 
 sub delete_cached_prop {
     my $self = shift;
     my $prop = shift;
 
-    delete $PROP_CACHE->{$self->uuid}->{$prop};
+    delete $PROP_CACHE->{ $self->uuid }->{$prop};
 }
 
 sub clear_prop_cache {
@@ -140,69 +140,78 @@ sub clear_prop_cache {
     delete $PROP_CACHE->{$replica_uuid};
 }
 
-use constant scheme   => 'sqlite';
-use constant userdata_dir    => 'userdata';
+use constant scheme       => 'sqlite';
+use constant userdata_dir => 'userdata';
+
 sub BUILD {
     my $self = shift;
     my $args = shift;
     Carp::cluck() unless ( $args->{app_handle} );
     for ( $self->{url} ) {
+
         #s/^sqlite://;    # url-based constructor in ::replica should do better
         s{/$}{};
     }
-   $self->_check_for_upgrades if ($self->replica_exists);
-        
+    $self->_check_for_upgrades if ( $self->replica_exists );
 
 }
 
 sub _check_for_upgrades {
     my $self = shift;
-   if  ( $self->replica_version && $self->replica_version < 2) { $self->_upgrade_replica_to_v2(); } 
-   if  ( $self->replica_version && $self->replica_version < 3) { $self->_upgrade_replica_to_v3(); } 
-   if  ( $self->replica_version && $self->replica_version < 5) { $self->_upgrade_replica_to_v5(); }
+    if ( $self->replica_version && $self->replica_version < 2 ) {
+        $self->_upgrade_replica_to_v2();
+    }
+    if ( $self->replica_version && $self->replica_version < 3 ) {
+        $self->_upgrade_replica_to_v3();
+    }
+    if ( $self->replica_version && $self->replica_version < 5 ) {
+        $self->_upgrade_replica_to_v5();
+    }
 
 }
 
-
-
-
 sub __fetch_data {
-    my $self = shift;
+    my $self  = shift;
     my $table = shift;
-    my $key = shift;
+    my $key   = shift;
 
-	$key = lc($key);
+    $key = lc($key);
     my $sth = $self->dbh->prepare("SELECT value FROM $table WHERE key = ?");
     $sth->execute($key);
-       
+
     my $results = $sth->fetchrow_arrayref;
-    return $results?$results->[0] : undef;
+    return $results ? $results->[0] : undef;
 }
 
 sub __store_data {
     my $self = shift;
-    my %args = validate(@_, { key => 1, value => 1, table => 1});
-	$args{key} = lc($args{key});
+    my %args = validate( @_, { key => 1, value => 1, table => 1 } );
+    $args{key} = lc( $args{key} );
     $self->dbh->do( "DELETE FROM $args{table} WHERE key = ?", {}, $args{key} );
-    $self->dbh->do( "INSERT INTO $args{table} (key,value) VALUES(?,?)", {}, $args{key}, $args{value} );
+    $self->dbh->do( "INSERT INTO $args{table} (key,value) VALUES(?,?)",
+        {}, $args{key}, $args{value} );
 
 }
 
 sub fetch_local_metadata {
     my $self = shift;
-    my $key = shift;
+    my $key  = shift;
     return $self->__fetch_data( 'local_metadata', $key );
 }
 
 sub store_local_metadata {
     my $self = shift;
-    my ($key, $value) = (@_);
-    $self->__store_data( table => 'local_metadata', key => $key, value => $value);
+    my ( $key, $value ) = (@_);
+    $self->__store_data(
+        table => 'local_metadata',
+        key   => $key,
+        value => $value
+    );
 }
 
 sub _fetch_userdata {
     my $self = shift;
-    my $key = shift;
+    my $key  = shift;
     return $self->__fetch_data( 'userdata', $key );
 }
 
@@ -211,31 +220,19 @@ sub _store_userdata {
     $self->__store_data( table => 'userdata', @_ );
 }
 
-=head2 replica_exists
-
-Returns true if the replica already exists / has been initialized.
-Returns false otherwise.
-
-=cut
 
 sub replica_exists {
     my $self = shift;
     return defined $self->db_file && -f $self->db_file ? 1 : 0;
 }
 
-=head2 replica_version
 
-Returns this replica's version.
+sub replica_version {
+    die "replica_version is read-only; you want set_replica_version."
+      if @_ > 1;
+    shift->_replica_version;
+}
 
-=cut
-
-sub replica_version { die "replica_version is read-only; you want set_replica_version." if @_ > 1; shift->_replica_version }
-
-=head2 set_replica_version
-
-Sets the replica's version to the given integer.
-
-=cut
 
 sub set_replica_version {
     my $self    = shift;
@@ -243,7 +240,7 @@ sub set_replica_version {
 
     $self->_replica_version($version);
 
-    $self->store_local_metadata( 'replica-version' => $version,);
+    $self->store_local_metadata( 'replica-version' => $version, );
 
     return $version;
 }
@@ -262,28 +259,29 @@ use constant can_read_changesets => 1;
 sub can_write_changesets {1}
 sub can_write_records    {1}
 
-
 sub _on_initialize_create_paths {
-		my $self = shift;
-		# We initialize the root, so we just insert '' here
-		return ('');
-	}
+    my $self = shift;
 
+    # We initialize the root, so we just insert '' here
+    return ('');
+}
 
 sub initialize_backend {
     my $self = shift;
     my %args = validate(
         @_,
-        {   db_uuid    => 0,
+        {
+            db_uuid    => 0,
             resdb_uuid => 0,
         }
     );
 
-    for ($self->schema) {
+    for ( $self->schema ) {
         $self->dbh->do($_) || warn $self->dbh->errstr;
     }
 
-    $self->set_db_uuid( $args{'db_uuid'} || $self->uuid_generator->create_str );
+    $self->set_db_uuid( $args{'db_uuid'}
+          || $self->uuid_generator->create_str );
     $self->set_replica_uuid( $self->uuid_generator->create_str );
     $self->set_replica_version(3);
     $self->resolution_db_handle->initialize( db_uuid => $args{resdb_uuid} )
@@ -298,35 +296,27 @@ sub latest_sequence_no {
     return $sth->fetchrow_array || 0;
 }
 
-=head2 uuid
-
-Return the replica  UUID
-
-=cut
 
 sub uuid {
     my $self = shift;
-    $self->_uuid( $self->fetch_local_metadata('replica-uuid') ) unless $self->_uuid;
+    $self->_uuid( $self->fetch_local_metadata('replica-uuid') )
+      unless $self->_uuid;
     return $self->_uuid;
 }
 
 sub set_replica_uuid {
     my $self = shift;
     my $uuid = shift;
-    $self->store_local_metadata( 'replica-uuid' => $uuid);
+    $self->store_local_metadata( 'replica-uuid' => $uuid );
 
 }
 
 sub set_db_uuid {
     my $self = shift;
     my $uuid = shift;
-    $self->store_local_metadata( 'database-uuid', => $uuid);
+    $self->store_local_metadata( 'database-uuid', => $uuid );
     $self->SUPER::set_db_uuid($uuid);
-};
-
-=head1 Internals of record handling
-
-=cut
+}
 
 sub _write_record {
     my $self   = shift;
@@ -346,20 +336,20 @@ sub _write_record_to_db {
 
     for ( keys %{ $args{'props'} } ) {
         delete $args{'props'}->{$_}
-            if ( !defined $args{'props'}->{$_} || $args{'props'}->{$_} eq '' );
+          if ( !defined $args{'props'}->{$_} || $args{'props'}->{$_} eq '' );
     }
 
-    if ($self->record_exists( uuid => $args{uuid}, type => $args{type} ) ) {
-        $self->_delete_record_props_from_db( uuid => $args{uuid} ) 
+    if ( $self->record_exists( uuid => $args{uuid}, type => $args{type} ) ) {
+        $self->_delete_record_props_from_db( uuid => $args{uuid} );
     } else {
-        $self->dbh->do( "INSERT INTO records (type, uuid) VALUES (?,?)", {},
-        $args{type}, $args{uuid} );
+        $self->dbh->do( "INSERT INTO records (type, uuid) VALUES (?,?)",
+            {}, $args{type}, $args{uuid} );
 
     }
     $self->dbh->do(
-        "INSERT INTO record_props (uuid, prop, value) VALUES (?,?,?)", {},
-        $args{uuid}, $_, $args{props}->{$_} )
-    for ( keys %{ $args{props} } );
+        "INSERT INTO record_props (uuid, prop, value) VALUES (?,?,?)",
+        {}, $args{uuid}, $_, $args{props}->{$_} )
+      for ( keys %{ $args{props} } );
 
 }
 
@@ -367,7 +357,7 @@ sub _delete_record_from_db {
     my $self = shift;
     my %args = validate( @_, { uuid => 1 } );
 
-    $self->dbh->do("DELETE FROM records where uuid = ?", {},$args{uuid});
+    $self->dbh->do( "DELETE FROM records where uuid = ?", {}, $args{uuid} );
     $self->_delete_record_props_from_db(%args);
 }
 
@@ -375,27 +365,23 @@ sub _delete_record_props_from_db {
     my $self = shift;
     my %args = validate( @_, { uuid => 1 } );
 
-    $self->dbh->do("DELETE FROM record_props where uuid = ?", {}, $args{uuid});
+    $self->dbh->do( "DELETE FROM record_props where uuid = ?",
+        {}, $args{uuid} );
     $self->delete_cached_prop( $args{uuid} );
 }
 
-=head2 traverse_changesets { after => SEQUENCE_NO, UNTIL => SEQUENCE_NO, callback => sub { } } 
-
-Walks through all changesets from $after to $until, calling $callback on each.
-
-If no $until is specified, the latest changeset is assumed.
-
-=cut
 
 sub traverse_changesets {
     my $self = shift;
     my %args = validate(
         @_,
-        {   after           => 1,
-            callback        => 1,
-            until           => 0,
-            reverse         => 0,
-            before_load_changeset_callback => { type => CODEREF, optional => 1},
+        {
+            after    => 1,
+            callback => 1,
+            until    => 0,
+            reverse  => 0,
+            before_load_changeset_callback =>
+              { type => CODEREF, optional => 1 },
             reporting_callback => { type => CODEREF, optional => 1 },
 
             load_changesets => { default => 1 }
@@ -415,24 +401,22 @@ sub traverse_changesets {
     for my $rev (@range) {
 
         if ( $args{'before_load_changeset_callback'} ) {
-            my $continue = $args{'before_load_changeset_callback'}->(
-                changeset_metadata => $self->_changeset_index_entry(
-                    sequence_no => $rev,
-                )
-            );
+            my $continue =
+              $args{'before_load_changeset_callback'}->( changeset_metadata =>
+                  $self->_changeset_index_entry( sequence_no => $rev, ) );
         }
 
         $self->log_debug("Fetching changeset $rev");
         my $data;
         if ( $args{load_changesets} ) {
             $data = $self->_load_changeset_from_db( sequence_no => $rev );
-            $args{callback}->( changeset =>$data);
+            $args{callback}->( changeset => $data );
         } else {
-            $data = $self->_changeset_index_entry( sequence_no => $rev);
-            $args{callback}->(changeset_metadata => $data);
+            $data = $self->_changeset_index_entry( sequence_no => $rev );
+            $args{callback}->( changeset_metadata => $data );
 
         }
-        $args{reporting_callback}->($data) if ($args{reporting_callback});
+        $args{reporting_callback}->($data) if ( $args{reporting_callback} );
 
     }
 }
@@ -440,59 +424,51 @@ sub traverse_changesets {
 sub _changeset_index_entry {
     my $self = shift;
     my %args = ( sequence_no => undef, @_ );
-    my $row  = $self->_load_changeset_metadata_from_db( sequence_no => $args{sequence_no} );
-    my $data = [ $row->{sequence_no}, $row->{original_source_uuid}, $row->{original_sequence_no}, $row->{sha1} ];
+    my $row  = $self->_load_changeset_metadata_from_db(
+        sequence_no => $args{sequence_no} );
+    my $data = [
+        $row->{sequence_no},          $row->{original_source_uuid},
+        $row->{original_sequence_no}, $row->{sha1}
+    ];
     return $data;
 }
 
-
 sub read_changeset_index {
-    my $self =shift;
+    my $self  = shift;
     my $index = '';
     $self->traverse_changesets(
-                after=> 0,
-                load_changesets => 0,
-                callback => sub {
-                    my %args = (@_);
-                    my $data            = $args{changeset_metadata};
-                    my $changeset_index_line = pack( 'Na16NH40',
-                        $data->[0],
-                        $self->uuid_generator->from_string( $data->[1]),
-                        $data->[2],
-                        $data->[3]);
-                    $index .= $changeset_index_line;
-                }
-            );
-return \$index;
+        after           => 0,
+        load_changesets => 0,
+        callback        => sub {
+            my %args                 = (@_);
+            my $data                 = $args{changeset_metadata};
+            my $changeset_index_line = pack( 'Na16NH40',
+                $data->[0], $self->uuid_generator->from_string( $data->[1] ),
+                $data->[2], $data->[3] );
+            $index .= $changeset_index_line;
+        }
+    );
+    return \$index;
 
 }
 
-=head2 changesets_for_record { uuid => $uuid, type => $type, limit => $int }
-
-Returns an ordered set of changeset objects for all changesets containing
-changes to this object. 
-
-If "limit" is specified, only returns that many changesets (starting from record creation).
-
-Note that changesets may include changes to other records
-
-=cut
 
 sub changesets_for_record {
     my $self = shift;
     my %args = validate( @_, { uuid => 1, type => 1, limit => 0 } );
 
-    my $statement = "SELECT DISTINCT changesets.* "
-            . "FROM changes, changesets "
-            . "WHERE  changesets.sequence_no = changes.changeset "
-            . "AND changes.record = ?";
+    my $statement =
+        "SELECT DISTINCT changesets.* "
+      . "FROM changes, changesets "
+      . "WHERE  changesets.sequence_no = changes.changeset "
+      . "AND changes.record = ?";
 
-    if (defined $args{limit}) {
-        $statement .= " ORDER BY changesets.sequence_no LIMIT ".$args{limit};
+    if ( defined $args{limit} ) {
+        $statement .= " ORDER BY changesets.sequence_no LIMIT " . $args{limit};
 
     }
 
-    my $sth = $self->dbh->prepare( $statement    );
+    my $sth = $self->dbh->prepare($statement);
 
     require Prophet::ChangeSet;
     $sth->execute( $args{uuid} );
@@ -506,19 +482,19 @@ sub changesets_for_record {
     return @changesets;
 }
 
-
 sub fetch_serialized_changeset {
     my $self = shift;
-    my %args = validate(@_, { sha1 => 1 });
-    my $cs = $self->_load_changeset_from_db(sha1 => $args{sha1});
+    my %args = validate( @_, { sha1 => 1 } );
+    my $cs   = $self->_load_changeset_from_db( sha1 => $args{sha1} );
     return $cs->canonical_json_representation;
-}   
+}
 
 sub _load_changeset_from_db {
     my $self = shift;
     my %args = validate(
         @_,
-        {   sequence_no => 0,
+        {
+            sequence_no => 0,
             sha1        => 0
 
         }
@@ -531,7 +507,8 @@ sub _load_changeset_metadata_from_db {
     my $self = shift;
     my %args = validate(
         @_,
-        {   sequence_no => 0,
+        {
+            sequence_no => 0,
             sha1        => 0
 
         }
@@ -544,45 +521,58 @@ sub _load_changeset_metadata_from_db {
         $attr = 'sha1';
         @bind = ( $args{sha1} );
     } else {
-        die "$self->_load_changeset_from_db called with neither a sequence_no nor a sha1";
+        die
+          "$self->_load_changeset_from_db called with neither a sequence_no nor a sha1";
     }
-    my $sth = $self->dbh->prepare( "SELECT creator, created, sequence_no, "
-            . "original_source_uuid, original_sequence_no, "
-            . "is_nullification, is_resolution, sha1 from changesets "
-            . "WHERE $attr = ?" );
+    my $sth =
+      $self->dbh->prepare( "SELECT creator, created, sequence_no, "
+          . "original_source_uuid, original_sequence_no, "
+          . "is_nullification, is_resolution, sha1 from changesets "
+          . "WHERE $attr = ?" );
     $sth->execute(@bind);
     my $data = $sth->fetchrow_hashref;
 
 }
 
-
 sub _instantiate_changeset_from_db {
     my $self = shift;
     my $data = shift;
     require Prophet::ChangeSet;
-    my $changeset = Prophet::ChangeSet->new(%$data, source_uuid => $self->uuid );
+    my $changeset =
+      Prophet::ChangeSet->new( %$data, source_uuid => $self->uuid );
 
-    
-    my $sth = $self->dbh->prepare("SELECT id, record, change_type, record_type from changes WHERE changeset = ?");
-    $sth->execute($changeset->sequence_no);
-    while (my $row = $sth->fetchrow_hashref) {
-        my $change_id = delete $row->{id};
+    my $sth = $self->dbh->prepare(
+        "SELECT id, record, change_type, record_type from changes WHERE changeset = ?"
+    );
+    $sth->execute( $changeset->sequence_no );
+    while ( my $row = $sth->fetchrow_hashref ) {
+        my $change_id   = delete $row->{id};
         my $record_type = delete $row->{record_type};
 
-        my $change = Prophet::Change->new( record_uuid => $row->{record},
-                change_type => $row->{change_type}, record_type => $record_type );
-        my $propchange_sth = $self->dbh->prepare("SELECT name, old_value, new_value FROM prop_changes WHERE change = ?");
+        my $change = Prophet::Change->new(
+            record_uuid => $row->{record},
+            change_type => $row->{change_type},
+            record_type => $record_type
+        );
+        my $propchange_sth = $self->dbh->prepare(
+            "SELECT name, old_value, new_value FROM prop_changes WHERE change = ?"
+        );
         $propchange_sth->execute($change_id);
-        while (my $pc = $propchange_sth->fetchrow_hashref) {
-            $change->add_prop_change( name => $pc->{name}, old => $pc->{old_value}, new => $pc->{new_value});
+        while ( my $pc = $propchange_sth->fetchrow_hashref ) {
+            $change->add_prop_change(
+                name => $pc->{name},
+                old  => $pc->{old_value},
+                new  => $pc->{new_value}
+            );
         }
-        push @{$changeset->changes}, $change;
+        push @{ $changeset->changes }, $change;
     }
 
-    if(!$data->{sha1}) {
-        my $sha1 = $changeset->calculate_sha1();
-         my $update_sth = $self->dbh->prepare('UPDATE changesets set sha1 = ? where sequence_no = ?');
-        $update_sth->execute($sha1, $changeset->sequence_no);
+    if ( !$data->{sha1} ) {
+        my $sha1       = $changeset->calculate_sha1();
+        my $update_sth = $self->dbh->prepare(
+            'UPDATE changesets set sha1 = ? where sequence_no = ?');
+        $update_sth->execute( $sha1, $changeset->sequence_no );
         $changeset->sha1($sha1);
 
     }
@@ -592,8 +582,12 @@ sub _instantiate_changeset_from_db {
 
 sub begin_edit {
     my $self = shift;
-    my %args = validate( @_, {   source => 0,    # the changeset that we're replaying, if applicable
-        });
+    my %args = validate(
+        @_,
+        {
+            source => 0,    # the changeset that we're replaying, if applicable
+        }
+    );
 
     my $source = $args{source};
 
@@ -601,8 +595,14 @@ sub begin_edit {
     my $created = $source && $source->created;
 
     require Prophet::ChangeSet;
-    my $changeset = Prophet::ChangeSet->new( {   source_uuid => $self->uuid, creator     => $creator, $created ? ( created => $created ) : (), });
-    
+    my $changeset = Prophet::ChangeSet->new(
+        {
+            source_uuid => $self->uuid,
+            creator     => $creator,
+            $created ? ( created => $created ) : (),
+        }
+    );
+
     $self->current_edit($changeset);
     $self->current_edit_records( [] );
     $self->dbh->begin_work;
@@ -613,33 +613,36 @@ sub _set_original_source_metadata_for_current_edit {
     my $self = shift;
     my ($changeset) = validate_pos( @_, { isa => 'Prophet::ChangeSet' } );
 
-    $self->current_edit->original_source_uuid( $changeset->original_source_uuid );
-    $self->current_edit->original_sequence_no( $changeset->original_sequence_no );
+    $self->current_edit->original_source_uuid(
+        $changeset->original_source_uuid );
+    $self->current_edit->original_sequence_no(
+        $changeset->original_sequence_no );
 }
 
 sub commit_edit {
-    my $self     = shift;
-    $self->current_edit->original_source_uuid( $self->uuid ) unless ( $self->current_edit->original_source_uuid );
+    my $self = shift;
+    $self->current_edit->original_source_uuid( $self->uuid )
+      unless ( $self->current_edit->original_source_uuid );
 
+    my $local_id = $self->_write_changeset_to_db( $self->current_edit );
 
-    my $local_id = $self->_write_changeset_to_db($self->current_edit);
     # XXX TODO SET original_sequence_no
     $self->dbh->commit;
     $self->current_edit(undef);
 }
 
 sub _write_changeset_to_db {
-    my $self = shift;
+    my $self      = shift;
     my $changeset = shift;
 
     my $sha1 = $changeset->calculate_sha1();
 
     $self->dbh->do(
         "INSERT INTO changesets "
-            . "(creator, created,"
-            . "original_source_uuid, original_sequence_no, "
-            . "is_nullification, is_resolution, sha1) "
-            . "VALUES(?,?,?,?,?,?,?)", {},
+          . "(creator, created,"
+          . "original_source_uuid, original_sequence_no, "
+          . "is_nullification, is_resolution, sha1) "
+          . "VALUES(?,?,?,?,?,?,?)", {},
         $changeset->creator, $changeset->created,
 
         $changeset->original_source_uuid,
@@ -649,43 +652,49 @@ sub _write_changeset_to_db {
 
     );
 
-    my $local_id = $self->dbh->last_insert_id(undef, undef, 'changesets', 'sequence_no');
+    my $local_id =
+      $self->dbh->last_insert_id( undef, undef, 'changesets', 'sequence_no' );
 
     $self->dbh->do(
         "UPDATE changesets set original_sequence_no = sequence_no
             WHERE sequence_no = ?", {}, $local_id
     ) unless defined $changeset->original_sequence_no;
 
-    for my $change (@{$changeset->changes}) {
-        $self->_write_change_to_db($change, $local_id);
+    for my $change ( @{ $changeset->changes } ) {
+        $self->_write_change_to_db( $change, $local_id );
     }
 
     return $local_id;
 }
 
 sub _write_change_to_db {
-    my $self = shift;
-    my $change = shift;
+    my $self         = shift;
+    my $change       = shift;
     my $changeset_id = shift;
 
     $self->dbh->do(
         "INSERT INTO changes (record, changeset, change_type,
-        record_type) VALUES (?,?,?,?)", {}, $change->record_uuid, $changeset_id,
+        record_type) VALUES (?,?,?,?)", {}, $change->record_uuid,
+        $changeset_id,
         $change->change_type, $change->record_type
     );
-    my $change_id = $self->dbh->last_insert_id(undef, undef, 'changes', 'id');
-    for my $pc (@{$change->prop_changes}) {
-        $self->_write_prop_change_to_db($change_id, $pc);
+    my $change_id =
+      $self->dbh->last_insert_id( undef, undef, 'changes', 'id' );
+    for my $pc ( @{ $change->prop_changes } ) {
+        $self->_write_prop_change_to_db( $change_id, $pc );
     }
 
 }
 
 sub _write_prop_change_to_db {
-    my $self = shift;
+    my $self   = shift;
     my $change = shift;
-    my $pc = shift;
+    my $pc     = shift;
 
-    $self->dbh->do("INSERT INTO prop_changes (change, name, old_value, new_value) VALUES (?,?,?,?)", {}, $change, $pc->name, $pc->old_value, $pc->new_value);
+    $self->dbh->do(
+        "INSERT INTO prop_changes (change, name, old_value, new_value) VALUES (?,?,?,?)",
+        {}, $change, $pc->name, $pc->old_value, $pc->new_value
+    );
 
 }
 
@@ -702,9 +711,23 @@ sub create_record {
 
     my $inside_edit = $self->current_edit ? 1 : 0;
     $self->begin_edit() unless ($inside_edit);
-    $self->_write_record_to_db( type  => $args{'type'}, uuid  => $args{'uuid'}, props => $args{'props'});
-    my $change = Prophet::Change->new( {   record_type => $args{'type'}, record_uuid => $args{'uuid'}, change_type => 'add_file' });
-    $change->add_prop_change( name => $_, old  => undef, new  => $args{props}->{$_}) for (keys %{$args{props}});
+    $self->_write_record_to_db(
+        type  => $args{'type'},
+        uuid  => $args{'uuid'},
+        props => $args{'props'}
+    );
+    my $change = Prophet::Change->new(
+        {
+            record_type => $args{'type'},
+            record_uuid => $args{'uuid'},
+            change_type => 'add_file'
+        }
+    );
+    $change->add_prop_change(
+        name => $_,
+        old  => undef,
+        new  => $args{props}->{$_}
+    ) for ( keys %{ $args{props} } );
     $self->current_edit->add_change( change => $change );
     $self->commit_edit unless ($inside_edit);
 }
@@ -715,9 +738,15 @@ sub delete_record {
 
     my $inside_edit = $self->current_edit ? 1 : 0;
     $self->begin_edit() unless ($inside_edit);
-    $self->_delete_record_from_db(uuid => $args{uuid});
+    $self->_delete_record_from_db( uuid => $args{uuid} );
 
-    my $change = Prophet::Change->new( {   record_type => $args{'type'}, record_uuid => $args{'uuid'}, change_type => 'delete' });
+    my $change = Prophet::Change->new(
+        {
+            record_type => $args{'type'},
+            record_uuid => $args{'uuid'},
+            change_type => 'delete'
+        }
+    );
     $self->current_edit->add_change( change => $change );
 
     $self->commit_edit() unless ($inside_edit);
@@ -734,7 +763,8 @@ sub set_record_props {
     # clear the cache  before computing the diffs. this is probably paranoid
     $self->delete_cached_prop( $args{uuid} );
 
-    my $old_props = $self->get_record_props( uuid => $args{'uuid'}, type => $args{'type'});
+    my $old_props =
+      $self->get_record_props( uuid => $args{'uuid'}, type => $args{'type'} );
     my %new_props = %$old_props;
 
     for my $prop ( keys %{ $args{props} } ) {
@@ -745,13 +775,27 @@ sub set_record_props {
         }
     }
 
-    $self->_write_record_to_db( type  => $args{'type'}, uuid  => $args{'uuid'}, props => \%new_props);
+    $self->_write_record_to_db(
+        type  => $args{'type'},
+        uuid  => $args{'uuid'},
+        props => \%new_props
+    );
 
     # Clear the cache now that we've actually written out changed props
     $self->delete_cached_prop( $args{uuid} );
 
-    my $change = Prophet::Change->new( {   record_type => $args{'type'}, record_uuid => $args{'uuid'}, change_type => 'update_file' });
-    $change->add_prop_change( name => $_, old  => $old_props->{$_}, new  => $args{props}->{$_}) for (keys %{$args{props}});
+    my $change = Prophet::Change->new(
+        {
+            record_type => $args{'type'},
+            record_uuid => $args{'uuid'},
+            change_type => 'update_file'
+        }
+    );
+    $change->add_prop_change(
+        name => $_,
+        old  => $old_props->{$_},
+        new  => $args{props}->{$_}
+    ) for ( keys %{ $args{props} } );
     $self->current_edit->add_change( change => $change );
     $self->commit_edit() unless ($inside_edit);
 
@@ -761,9 +805,10 @@ sub set_record_props {
 sub get_record_props {
     my $self = shift;
     my %args = ( uuid => undef, type => undef, @_ )
-        ;    # validate is slooow validate( @_, { uuid => 1, type => 1 } );
+      ;    # validate is slooow validate( @_, { uuid => 1, type => 1 } );
     unless ( $self->has_cached_prop( $args{uuid} ) ) {
-        my $sth = $self->dbh->prepare("SELECT prop, value from record_props WHERE uuid = ?");
+        my $sth = $self->dbh->prepare(
+            "SELECT prop, value from record_props WHERE uuid = ?");
         $sth->execute( $args{uuid} );
         my $items = $sth->fetchall_arrayref;
         $self->set_cached_prop( $args{uuid}, { map {@$_} @$items } );
@@ -774,45 +819,49 @@ sub get_record_props {
 sub record_exists {
     my $self = shift;
     my %args = validate( @_, { uuid => 1, type => 1 } );
-    return undef unless $args{'uuid'};
+    return unless $args{'uuid'};
 
-    my $sth = $self->dbh->prepare("SELECT luid from records WHERE type = ? AND uuid = ?");
-    $sth->execute($args{type}, $args{uuid});
+    my $sth = $self->dbh->prepare(
+        "SELECT luid from records WHERE type = ? AND uuid = ?");
+    $sth->execute( $args{type}, $args{uuid} );
     return $sth->fetchrow_array;
 
 }
 
-=head2 list_records { type => $type }
-
-Returns a reference to a list of record objects for all records of type $type.
-
-Order is not guaranteed.
-
-=cut
 
 sub list_records {
     my $self = shift;
     my %args = validate( @_ => { type => 1, record_class => 1 } );
     my @data;
-    my $sth = $self->dbh->prepare("SELECT records.uuid, records.luid, record_props.prop, record_props.value ".
-        "FROM records, record_props ".
-        "WHERE records.uuid = record_props.uuid AND records.type = ?");
-    $sth->execute($args{type});
+    my $sth = $self->dbh->prepare(
+        "SELECT records.uuid, records.luid, record_props.prop, record_props.value "
+          . "FROM records, record_props "
+          . "WHERE records.uuid = record_props.uuid AND records.type = ?" );
+    $sth->execute( $args{type} );
 
     my %found;
 
-    for (@{$sth->fetchall_arrayref}) { 
-        $found{$_->[0]}->{luid} = $_->[1];
-        $found{$_->[0]}->{props}->{$_->[2]} = $_->[3];
-    } 
+    for ( @{ $sth->fetchall_arrayref } ) {
+        $found{ $_->[0] }->{luid} = $_->[1];
+        $found{ $_->[0] }->{props}->{ $_->[2] } = $_->[3];
+    }
 
+    for my $uuid ( keys %found ) {
+        my $record = $args{record_class}->new(
+            {
+                app_handle => $self->app_handle,
+                handle     => $self,
+                type       => $args{type}
+            }
+        );
+        $record->_instantiate_from_hash(
+            uuid => $uuid,
+            luid => $found{$uuid}->{luid}
+        );
 
-    for my $uuid (keys %found) {
-        my $record = $args{record_class}->new( { app_handle => $self->app_handle,  handle => $self, type => $args{type} } );
-        $record->_instantiate_from_hash( uuid => $uuid, luid => $found{$uuid}->{luid});
         #$self->prop_cache->{$uuid} = $found{$uuid}->{props};
-        push @data, $record;    
-    } 
+        push @data, $record;
+    }
     return \@data;
 }
 
@@ -821,24 +870,19 @@ sub list_types {
 
     my $sth = $self->dbh->prepare("SELECT DISTINCT type from records");
     $sth->execute();
-    return [ map { $_->[0]} @{$sth->fetchall_arrayref}];
+    return [ map { $_->[0] } @{ $sth->fetchall_arrayref } ];
 }
 
 sub type_exists {
     my $self = shift;
-    my %args = (type =>undef, @_);
-    my $sth = $self->dbh->prepare("SELECT type from records WHERE type = ? LIMIT 1");
-    $sth->execute($args{type});
+    my %args = ( type => undef, @_ );
+    my $sth =
+      $self->dbh->prepare("SELECT type from records WHERE type = ? LIMIT 1");
+    $sth->execute( $args{type} );
     return $sth->fetchrow_array;
 
 }
 
-=head2 read_userdata_file
-
-Returns the contents of the given file in this replica's userdata directory.
-Returns C<undef> if the file does not exist.
-
-=cut
 
 sub read_userdata {
     my $self = shift;
@@ -846,11 +890,6 @@ sub read_userdata {
     return $self->_fetch_userdata( $args{path} );
 }
 
-=head2 write_userdata_file
-
-Writes the given string to the given file in this replica's userdata directory.
-
-=cut
 
 sub write_userdata {
     my $self = shift;
@@ -861,18 +900,14 @@ sub write_userdata {
     );
 }
 
-
-=head1 Working with luids
-
-=cut
-
 sub find_or_create_luid {
     my $self = shift;
-    my %args = (uuid => undef, type => undef, @_); # validate is slooow validate( @_, { uuid => 1, type => 1 } );
-    return undef unless $args{'uuid'};
+    my %args = ( uuid => undef, type => undef, @_ )
+      ;    # validate is slooow validate( @_, { uuid => 1, type => 1 } );
+    return unless $args{'uuid'};
 
     my $sth = $self->dbh->prepare("SELECT luid from records WHERE uuid = ?");
-    $sth->execute( $args{uuid});
+    $sth->execute( $args{uuid} );
     return $sth->fetchrow_array;
 }
 
@@ -881,24 +916,23 @@ sub find_luid_by_uuid {
     my %args = validate( @_, { uuid => 1 } );
 
     my $sth = $self->dbh->prepare("SELECT luid from records WHERE uuid = ?");
-    $sth->execute( $args{uuid});
+    $sth->execute( $args{uuid} );
     return $sth->fetchrow_array;
 }
 
 sub find_uuid_by_luid {
     my $self = shift;
     my %args = validate( @_, { luid => 1 } );
-    return undef unless $args{'luid'};
+    return unless $args{'luid'};
 
     my $sth = $self->dbh->prepare("SELECT uuid from records WHERE luid = ?");
-    $sth->execute( $args{luid});
+    $sth->execute( $args{luid} );
     return $sth->fetchrow_array;
 }
 
-
 sub schema {
-	my $self = shift;
-	return (
+    my $self = shift;
+    return (
 
         q{
 CREATE TABLE records (
@@ -958,10 +992,9 @@ CREATE TABLE userdata (
         q{create index typeuuuid on records(type, uuid)},
         q{create index keyidx on userdata(key)}
 
-      );
+    );
 }
 
-
 sub _upgrade_replica_to_v2 {
     my $self = shift;
 
@@ -976,31 +1009,25 @@ sub _upgrade_replica_to_v2 {
     );
 
 }
+
 sub _upgrade_replica_to_v3 {
     my $self = shift;
 
     $self->_do_db_upgrades(
-        statements => [
-            q{ALTER TABLE changesets ADD COLUMN sha1 text}
-        ],
-        version => 3
+        statements => [q{ALTER TABLE changesets ADD COLUMN sha1 text}],
+        version    => 3
     );
 }
 
-
 sub _upgrade_replica_to_v5 {
     my $self = shift;
 
     $self->_do_db_upgrades(
-        statements => [
-            q{UPDATE local_metadata SET key = lower(key)}
-        ],
-        version => 5
+        statements => [q{UPDATE local_metadata SET key = lower(key)}],
+        version    => 5
     );
 }
 
-
-
 sub _do_db_upgrades {
     my $self = shift;
     my %args = (
@@ -1019,14 +1046,193 @@ sub _do_db_upgrades {
 
 }
 
-
 sub DEMOLISH {
     my $self = shift;
     $self->dbh->disconnect if ( $self->replica_exists and $self->dbh );
 }
 
-
 __PACKAGE__->meta->make_immutable;
 no Any::Moose;
 
 1;
+
+__END__
+
+=pod
+
+=head1 NAME
+
+Prophet::Replica::sqlite
+
+=head1 VERSION
+
+version 0.751
+
+=head1 METHODS
+
+=head2 replica_exists
+
+Returns true if the replica already exists / has been initialized. Returns
+false otherwise.
+
+=head2 replica_version
+
+Returns this replica's version.
+
+=head2 set_replica_version
+
+Sets the replica's version to the given integer.
+
+=head2 uuid
+
+Return the replica  UUID
+
+=head2 traverse_changesets { after => SEQUENCE_NO, UNTIL => SEQUENCE_NO, callback => sub { } } 
+
+Walks through all changesets from $after to $until, calling $callback on each.
+
+If no $until is specified, the latest changeset is assumed.
+
+=head2 changesets_for_record { uuid => $uuid, type => $type, limit => $int }
+
+Returns an ordered set of changeset objects for all changesets containing
+changes to this object.
+
+If "limit" is specified, only returns that many changesets (starting from
+record creation).
+
+Note that changesets may include changes to other records
+
+=head2 list_records { type => $type }
+
+Returns a reference to a list of record objects for all records of type $type.
+
+Order is not guaranteed.
+
+=head2 read_userdata_file
+
+Returns the contents of the given file in this replica's userdata directory.
+Returns C<undef> if the file does not exist.
+
+=head2 write_userdata_file
+
+Writes the given string to the given file in this replica's userdata directory.
+
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Jesse Vincent <jesse@bestpractical.com>
+
+=item *
+
+Chia-Liang Kao <clkao@bestpractical.com>
+
+=item *
+
+Christine Spang <christine@spang.cc>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2009 by Best Practical Solutions.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=head1 BUGS AND LIMITATIONS
+
+You can make new bug reports, and view existing ones, through the
+web interface at L<https://rt.cpan.org/Public/Dist/Display.html?Name=Prophet>.
+
+=head1 CONTRIBUTORS
+
+=over 4
+
+=item *
+
+Alex Vandiver <alexmv@bestpractical.com>
+
+=item *
+
+Casey West <casey@geeknest.com>
+
+=item *
+
+Cyril Brulebois <kibi@debian.org>
+
+=item *
+
+Florian Ragwitz <rafl@debian.org>
+
+=item *
+
+Ioan Rogers <ioanr@cpan.org>
+
+=item *
+
+Jonas Smedegaard <dr@jones.dk>
+
+=item *
+
+Kevin Falcone <falcone@bestpractical.com>
+
+=item *
+
+Lance Wicks <lw@judocoach.com>
+
+=item *
+
+Nelson Elhage <nelhage@mit.edu>
+
+=item *
+
+Pedro Melo <melo@simplicidade.org>
+
+=item *
+
+Rob Hoelz <rob@hoelz.ro>
+
+=item *
+
+Ruslan Zakirov <ruz@bestpractical.com>
+
+=item *
+
+Shawn M Moore <sartak@bestpractical.com>
+
+=item *
+
+Simon Wistow <simon@thegestalt.org>
+
+=item *
+
+Stephane Alnet <stephane@shimaore.net>
+
+=item *
+
+Unknown user <nobody@localhost>
+
+=item *
+
+Yanick Champoux <yanick@babyl.dyndns.org>
+
+=item *
+
+franck cuny <franck@lumberjaph.net>
+
+=item *
+
+robertkrimen <robertkrimen@gmail.com>
+
+=item *
+
+sunnavy <sunnavy@bestpractical.com>
+
+=back
+
+=cut
