@@ -5,10 +5,7 @@ extends 'Prophet::CLI';
 
 use App::Settings;
 
-has '+app_class' => (
-    default => 'App::Settings',
-);
-
+has '+app_class' => ( default => 'App::Settings', );
 
 __PACKAGE__->meta->make_immutable;
 no Any::Moose;
