@@ -4,10 +4,7 @@ extends 'Prophet::CLI';
 
 use App::WebToy;
 
-has 'app_class' => (
-    default => 'App::WebToy',
-);
-
+has 'app_class' => ( default => 'App::WebToy', );
 
 __PACKAGE__->meta->make_immutable;
 no Any::Moose;
